@@ -2,7 +2,7 @@ package Dezi;
 use warnings;
 use strict;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.004000';
 
 1;
 
@@ -50,6 +50,10 @@ only. You should read:
 
 the L<Dezi::Tutorial>
 
+=item 
+
+the L<Dezi::Config> documentation
+
 =item
 
 the L<Dezi::Server> class documentation
