@@ -6,7 +6,7 @@ use JSON;
 use Search::Tools::XML;
 use Scalar::Util qw( blessed );
 
-our $VERSION = '0.003000';
+our $VERSION = '0.004000';
 
 sub new {
     my $class       = shift;
@@ -299,7 +299,7 @@ See http://dev.perl.org/licenses/ for more information.
 
 =head1 SEE ALSO
 
-L<Search::OpenSearch>, L<SWISH::3>, L<SWISH::Prog::Lucy>,
+L<Search::OpenSearch>, L<SWISH::3>, L<Dezi::App>,
 L<Plack>, L<Lucy>
 
 =cut
